libbitcoinkernel_sys

Function kernel_block_manager_options_create

pub unsafe extern "C" fn kernel_block_manager_options_create(
    context: *const kernel_Context,
    blocks_directory: *const c_char,
    blocks_directory_len: usize,
) -> *mut kernel_BlockManagerOptions
@brief Create options for the block manager. The block manager is used internally by the chainstate manager for block storage and indexing.

@param[in] context Non-null, the created options will associate with this kernel context for the duration of their lifetime. The same context needs to be used when instantiating the chainstate manager. @param[in] blocks_directory Non-null, path string of the directory containing the block data. If the directory does not exist yet, it will be created. @return The allocated block manager options, or null on error.