libbitcoinkernel_sys

Function kernel_chainstate_manager_load_chainstate

pub unsafe extern "C" fn kernel_chainstate_manager_load_chainstate(
    context: *const kernel_Context,
    chainstate_load_options: *const kernel_ChainstateLoadOptions,
    chainstate_manager: *mut kernel_ChainstateManager,
) -> bool
@brief This function must be called to initialize the chainstate manager before doing validation tasks or interacting with its indexes.

@param[in] context Non-null. @param[in] chainstate_load_options Non-null, created by kernel_chainstate_load_options_create. @param[in] chainstate_manager Non-null, will load the chainstate(s) and initialize indexes. @return True on success, false on error.