Function kernel_chainstate_manager_options_create

pub unsafe extern "C" fn kernel_chainstate_manager_options_create(
    context: *const kernel_Context,
    data_directory: *const c_char,
    data_directory_len: usize,
    blocks_directory: *const c_char,
    blocks_directory_len: usize,
) -> *mut kernel_ChainstateManagerOptions
@brief Create options for the chainstate manager.

@param[in] context Non-null, the created options will associate with this kernel context for the duration of their lifetime. The same context needs to be used when instantiating the chainstate manager. @param[in] data_directory Non-null, path string of the directory containing the chainstate data. If the directory does not exist yet, it will be created. @param[in] blocks_directory Non-null, path string of the directory containing the block data. If the directory does not exist yet, it will be created. @return The allocated chainstate manager options, or null on error.