libbitcoinkernel_sys

Function kernel_chainstate_manager_options_set_worker_threads_num

pub unsafe extern "C" fn kernel_chainstate_manager_options_set_worker_threads_num(
    chainstate_manager_options: *mut kernel_ChainstateManagerOptions,
    worker_threads: c_int,
)
@brief Set the number of available worker threads used during validation.

@param[in] chainstate_manager_options Non-null, options to be set. @param[in] worker_threads The number of worker threads that should be spawned in the thread pool used for validation. The number must not be negative. When set to zero no parallel verification is done.