pub unsafe extern "C" fn kernel_context_options_set_chainparams(
context_options: *mut kernel_ContextOptions,
chain_parameters: *const kernel_ChainParameters,
)Expand description
@brief Sets the chain params for the context options. The context created with the options will be configured for these chain parameters.
@param[in] context_options Non-null, previously created by @ref kernel_context_options_create. @param[in] chain_parameters Is set to the context options.