pub unsafe extern "C" fn kernel_context_options_set_notifications(
context_options: *mut kernel_ContextOptions,
notifications: kernel_NotificationInterfaceCallbacks,
)Expand description
@brief Set the kernel notifications for the context options. The context created with the options will be configured with these notifications.
@param[in] context_options Non-null, previously created by @ref kernel_context_options_create. @param[in] notifications Is set to the context options.