Function kernel_disable_log_category

pub unsafe extern "C" fn kernel_disable_log_category(
    category: kernel_LogCategory,
)
@brief Disable a specific log category for the global internal logger. This function is not thread safe. Mutiple calls from different threads are allowed but must be synchronized. This changes a global setting and will override settings for all existing @ref kernel_LoggingConnection instances.

@param[in] category If kernel_LOG_ALL is chosen, all categories will be disabled.