libbitcoinkernel_sys

Function kernel_disable_logging

pub unsafe extern "C" fn kernel_disable_logging()
@brief This disables the global internal logger. No log messages will be buffered internally anymore once this is called and the buffer is cleared. This function should only be called once. Log messages will be buffered until this function is called, or a logging connection is created.