pub unsafe extern "C" fn kernel_get_block_index_from_genesis(
context: *const kernel_Context,
chainstate_manager: *mut kernel_ChainstateManager,
) -> *mut kernel_BlockIndexExpand description
@brief Get the block index entry of the genesis block.
@param[in] context Non-null. @param[in] chainstate_manager Non-null. @return The block index of the genesis block, or null on error.