Function kernel_get_block_index_from_hash

pub unsafe extern "C" fn kernel_get_block_index_from_hash(
    context: *const kernel_Context,
    chainstate_manager: *mut kernel_ChainstateManager,
    block_hash: *mut kernel_BlockHash,
) -> *mut kernel_BlockIndex
@brief Retrieve a block index by its block hash.

@param[in] context Non-null. @param[in] chainstate_manager Non-null. @param[in] block_hash Non-null. @return The block index of the block with the passed in hash, or null on error.