pub unsafe extern "C" fn kernel_get_block_index_from_height(
context: *const kernel_Context,
chainstate_manager: *mut kernel_ChainstateManager,
block_height: c_int,
) -> *mut kernel_BlockIndexExpand description
@brief Retrieve a block index by its height in the currently active chain. Once retrieved there is no guarantee that it remains in the active chain.
@param[in] context Non-null. @param[in] chainstate_manager Non-null. @param[in] block_height Height in the chain of the to be retrieved block index. @return The block index at a certain height in the currently active chain, or null on error.