Function kernel_get_block_index_from_tip

pub unsafe extern "C" fn kernel_get_block_index_from_tip(
    context: *const kernel_Context,
    chainstate_manager: *mut kernel_ChainstateManager,
) -> *mut kernel_BlockIndex
@brief Get the block index entry of the current chain tip. Once returned, there is no guarantee that it remains in the active chain.

@param[in] context Non-null. @param[in] chainstate_manager Non-null. @return The block index of the current tip.