Function kernel_get_next_block_index

pub unsafe extern "C" fn kernel_get_next_block_index(
    context: *const kernel_Context,
    chainstate_manager: *mut kernel_ChainstateManager,
    block_index: *const kernel_BlockIndex,
) -> *mut kernel_BlockIndex
@brief Return the next block index in the currently active chain, or null if the current block index is the tip, or is not in the currently active chain.

@param[in] context Non-null. @param[in] block_index Non-null. @param[in] chainstate_manager Non-null. @return The next block index in the currently active chain, or null on error.