Function kernel_get_transaction_undo_size

pub unsafe extern "C" fn kernel_get_transaction_undo_size(
    block_undo: *const kernel_BlockUndo,
    transaction_undo_index: u64,
) -> u64
@brief Returns the number of previous transaction outputs contained in the transaction undo data.

@param[in] block_undo Non-null, the block undo data from which tx_undo was retrieved from. @param[in] transaction_undo_index The index of the transaction undo data within the block undo data. @return The number of previous transaction outputs in the transaction.