pub unsafe extern "C" fn kernel_get_undo_output_by_index(
block_undo: *const kernel_BlockUndo,
transaction_undo_index: u64,
output_index: u64,
) -> *mut kernel_TransactionOutputExpand description
@brief Return a transaction output contained in the transaction undo data of a block undo data at a certain index.
@param[in] block_undo Non-null. @param[in] transaction_undo_index The index of the transaction undo data within the block undo data. @param[in] output_index The index of the to be retrieved transaction output within the transaction undo data. @return A transaction output pointer, or null on error.