pub unsafe extern "C" fn kernel_import_blocks(
context: *const kernel_Context,
chainstate_manager: *mut kernel_ChainstateManager,
block_file_paths: *mut *const c_char,
block_file_paths_lens: *mut usize,
block_file_paths_len: usize,
) -> boolExpand description
@brief May be called once the kernel_ChainstateManager is instantiated. Triggers the start of a reindex if the option was previously set for the chainstate and block manager. Can also import an array of existing block files selected by the user.
@param[in] context Non-null. @param[in] chainstate_manager Non-null. @param[in] block_file_paths Nullable, array of block files described by their full filesystem paths. @param[in] block_file_paths_len Length of the block_file_paths array. @return True if the import blocks call was completed successfully.