libbitcoinkernel_sys

Function kernel_read_block_undo_from_disk

pub unsafe extern "C" fn kernel_read_block_undo_from_disk(
    context: *const kernel_Context,
    chainstate_manager: *mut kernel_ChainstateManager,
    block_index: *const kernel_BlockIndex,
) -> *mut kernel_BlockUndo
@brief Reads the block undo data the passed in block index points to from disk and returns it.

@param[in] context Non-null. @param[in] chainstate_manager Non-null. @param[in] block_index Non-null. @return The read out block undo data, or null on error.