pub unsafe extern "C" fn kernel_copy_block_data(
block: *mut kernel_Block,
) -> *mut kernel_ByteArrayExpand description
@brief Copies block data into the returned byte array.
@param[in] block Non-null. @return Allocated byte array holding the block data, or null on error.