pub unsafe extern "C" fn kernel_logging_connection_create(
callback: kernel_LogCallback,
user_data: *const c_void,
options: kernel_LoggingOptions,
) -> *mut kernel_LoggingConnectionExpand description
@brief Start logging messages through the provided callback. Log messages produced before this function is first called are buffered and on calling this function are logged immediately.
@param[in] callback Non-null, function through which messages will be logged. @param[in] user_data Nullable, holds a user-defined opaque structure. Is passed back to the user through the callback. @param[in] options Sets formatting options of the log messages. @return A new kernel logging connection, or null on error.