pub unsafe extern "C" fn kernel_notifications_create(
callbacks: kernel_NotificationInterfaceCallbacks,
) -> *mut kernel_NotificationsExpand description
@brief Creates an object for holding the kernel notification callbacks.
@param[in] callbacks Holds the callbacks that will be invoked by the kernel notifications.