libbitcoinkernel_sys

Function kernel_transaction_output_create

pub unsafe extern "C" fn kernel_transaction_output_create(
    script_pubkey: *const kernel_ScriptPubkey,
    amount: i64,
) -> *mut kernel_TransactionOutput
@brief Create a transaction output from a script pubkey and an amount. @param[in] script_pubkey Non-null. @param[in] amount The amount associated with the script pubkey for this output. @return The transaction output.